#!/bin/bash

# Script to install and configure OfficeIRC Server 3 as a systemd service
# (C) Copyright 2025 Office IRC Inc.

OIRC_INSTALL_DIR="/opt/oirc"
OIRC_SERVICE_FILE="/opt/oirc/oirc.service"
OIRC_FILE="OfficeIRC.dll"
SYSTEMD_SERVICE_FILE="/etc/systemd/system/oirc.service"
dotnet_version="8.0"

if [[ $EUID -ne 0 ]]; then
  echo "This script must be run as root (using sudo)."
  exit 1
fi

if [[ ! -f "$OIRC_FILE" ]]; then
    echo "Application files are missing. Please check the archive contents has been fully extracted."
    exit 1
fi

echo "Installing .NET $dotnet_version Runtime..."
apt-get update
apt-get install -y aspnetcore-runtime-$dotnet_version

if [[ $? -ne 0 ]]; then
    echo "Failed to install .NET $dotnet_version Runtime. Exiting."
    exit 1
fi

echo "Installing OfficeIRC Server 3 to $OIRC_INSTALL_DIR..."
mkdir -p "$OIRC_INSTALL_DIR"
sudo cp -r . "$OIRC_INSTALL_DIR"

if [[ ! -f "$OIRC_SERVICE_FILE" ]]; then
    echo "oirc.service file not found in the downloaded archive. Please check the archive contents or provide a valid service file."
    exit 1
fi

echo "Configuring and installing systemd service..."
cp "$OIRC_SERVICE_FILE" "$SYSTEMD_SERVICE_FILE"

# Reload systemd daemon
systemctl daemon-reload

# Enable and start the service
systemctl enable oirc.service
systemctl start oirc.service

if [[ $? -eq 0 ]]; then
    echo "OfficeIRC Server 3 installed and service started successfully."
else
    echo "OfficeIRC Server 3 installation finished. However, there was a problem starting the service. Check the logs."
fi


echo "Checking service status:"
systemctl status oirc.service
echo ""
echo "You can view detailed logs with: journalctl -u oirc.service"

exit 0
